BrowserInstallation (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class BrowserInstallation

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.BrowserInstallation

    public class BrowserInstallation

extends java.lang.Object

Encapsulate useful settings of a browser installation discovered with a `BrowserLocator`

Constructor Summary
`BrowserInstallation(java.lang.String launcherFilePath, java.lang.String libraryPath)`

Method Summary
`java.lang.String` | `launcherFilePath()`
`java.lang.String` | `libraryPath()`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### BrowserInstallation

    public BrowserInstallation(java.lang.String launcherFilePath,
                               java.lang.String libraryPath)

Method Detail

### launcherFilePath

    public java.lang.String launcherFilePath()

### libraryPath

    public java.lang.String libraryPath()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.